Index: webrtc/modules/video_coding/codecs/interface/video_codec_interface.h |
diff --git a/webrtc/modules/video_coding/codecs/interface/video_codec_interface.h b/webrtc/modules/video_coding/codecs/interface/video_codec_interface.h |
index 6acd2d4320114b4e5543f3518ca1a7b5d496d1c1..411fbfdc79608d82caa76478cf86cc93d182cc33 100644 |
--- a/webrtc/modules/video_coding/codecs/interface/video_codec_interface.h |
+++ b/webrtc/modules/video_coding/codecs/interface/video_codec_interface.h |
@@ -43,16 +43,31 @@ struct CodecSpecificInfoVP8 { |
}; |
struct CodecSpecificInfoVP9 { |
- bool hasReceivedSLI; |
- uint8_t pictureIdSLI; |
- bool hasReceivedRPSI; |
- uint64_t pictureIdRPSI; |
- int16_t pictureId; // Negative value to skip pictureId. |
- bool nonReference; |
- uint8_t temporalIdx; |
- bool layerSync; |
- int tl0PicIdx; // Negative value to skip tl0PicIdx. |
- int8_t keyIdx; // Negative value to skip keyIdx. |
+ bool has_received_sli; |
+ uint8_t picture_id_sli; |
+ bool has_received_rpsi; |
+ uint64_t picture_id_rpsi; |
+ int16_t picture_id; // Negative value to skip pictureId. |
+ |
+ bool inter_pic_predicted; // This layer frame is dependent on previously |
+ // coded frame(s). |
+ bool flexible_mode; |
+ bool ss_data_available; |
+ |
+ int tl0_pic_idx; // Negative value to skip tl0PicIdx. |
+ uint8_t temporal_idx; |
+ uint8_t spatial_idx; |
+ bool temporal_up_switch; |
+ bool inter_layer_predicted; // Frame is dependent on directly lower spatial |
+ // layer frame. |
+ uint8_t gof_idx; |
+ |
+ // SS data. |
+ size_t num_spatial_layers; |
+ bool spatial_layer_resolution_present; |
+ uint16_t width[kMaxVp9NumberOfSpatialLayers]; |
+ uint16_t height[kMaxVp9NumberOfSpatialLayers]; |
+ GofInfoVP9 gof; |
}; |
struct CodecSpecificInfoGeneric { |